@@ -188,20 +188,52 @@ class TestCollectionHandler(BaseHandlerTestCase):
         self.assertEqual(handler.collection, self.collection)
 
     @inlineCallbacks
-    def test_get(self):
-        data = yield self.app_helper.get('/root/', parser='json_lines')
+    def test_get_stream(self):
+        data = yield self.app_helper.get('/root/?stream=true',
+                                         parser='json_lines')
         self.assertEqual(data, [{"id": "obj1"}, {"id": "obj2"}])
 
+    @inlineCallbacks
+    def test_get_page(self):
+        data = yield self.app_helper.get('/root/',
+                                         parser='json')
+        self.assertEqual(data, {
+            u'cursor': None,
+            u'data': [
+                {u'id': u'obj1'},
+                {u'id': u'obj2'},
+            ],
+        })
+
+    @inlineCallbacks
+    def test_get_page_bad_limit(self):
+        data = yield self.app_helper.get('/root/?max_results=a')
+        self.check_error_response(
+            data,
+            400,
+            "max_results must be an integer")
+
+    @inlineCallbacks
+    def test_get_page_multiple(self):
+        data = yield self.app_helper.get('/root/?max_results=1', parser='json')
+        self.assertEqual(data[u'cursor'], 1)
+        self.assertEqual(data[u'data'], [{u'id': u'obj1'}])
+
+        data = yield self.app_helper.get('/root/?max_results=1&cursor=1',
+                                         parser='json')
+        self.assertEqual(data[u'cursor'], None)
+        self.assertEqual(data[u'data'], [{u'id': u'obj2'}])
+
     @inlineCallbacks
     def test_get_usage_error(self):
-        self.collection.all = raise_usage_error
+        self.collection.page = raise_usage_error
         resp = yield self.app_helper.get('/root/')
         yield self.check_error_response(
             resp, 400, "Do not push the red button")
 
     @inlineCallbacks
     def test_get_server_error(self):
-        self.collection.all = raise_dummy_error
+        self.collection.page = raise_dummy_error
         resp = yield self.app_helper.get('/root/')
         yield self.check_error_response(
             resp, 500, "Failed to retrieve objects.")
@@ -436,7 +468,8 @@ class TestApiApplication(TestCase):
         app_helper = self.get_app_helper(
             collections=(('/:owner_id/store', collection_factory),))
         result = yield app_helper.request(
-            'GET', '/foo/store/', headers={"X-Owner-ID": "owner-1"})
+            'GET', '/foo/store/?stream=true',
+            headers={"X-Owner-ID": "owner-1"})
         content = yield result.content()
         self.assertEqual(json.loads(content), collection_data['foo'])
 
@@ -447,7 +480,7 @@ class TestApiApplication(TestCase):
         app_helper = self.get_app_helper(
             collections=(('/:owner_id/store', collection_factory),),
             preprocessor=None)
-        result = yield app_helper.request('GET', '/foo/store/')
+        result = yield app_helper.request('GET', '/foo/store/?stream=true')
         content = yield result.content()
         self.assertEqual(json.loads(content), collection_data['foo'])
 
@@ -458,7 +491,7 @@ class TestApiApplication(TestCase):
         app_helper = self.get_app_helper(
             collections=(('/:owner_id/store', collection_factory),),
             preprocessor=lambda handler: succeed("owner-1"))
-        result = yield app_helper.request('GET', '/foo/store/')
+        result = yield app_helper.request('GET', '/foo/store/?stream=true')
         content = yield result.content()
         self.assertEqual(json.loads(content), collection_data['foo'])
 
@@ -470,7 +503,7 @@ class TestApiApplication(TestCase):
         app_helper = self.get_app_helper(
             collections=(('/:owner_id/store', collection_factory),),
             preprocessor=owner_from_oauth2_bouncer(auth_server.url))
-        result = yield app_helper.request('GET', '/foo/store/')
+        result = yield app_helper.request('GET', '/foo/store/?stream=true')
         content = yield result.content()
         self.assertEqual(json.loads(content), collection_data['foo'])
 
